VADConfig class final

Configuration structure for VAD parameters

Inheritance
Implemented types
Available extensions

Constructors

VADConfig()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
end_speech_pad_frames int
Number of padding frames after speech end (default: 3 for v6)
getter/setter pair
frame_samples int
Number of samples per frame (512 for 16kHz v6, 256 for 8kHz v6)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
is_debug int
Enable debug logging (0 = false, 1 = true, using int32_t for FFI compatibility)
getter/setter pair
min_speech_frames int
Minimum speech frames for valid speech (default: 9 for v6)
getter/setter pair
negative_speech_threshold double
Threshold for detecting speech end (default: 0.35)
getter/setter pair
positive_speech_threshold double
Threshold for detecting speech start (default: 0.5)
getter/setter pair
pre_speech_pad_frames int
Number of frames to prepend before speech start (default: 3 for v6)
getter/setter pair
redemption_frames int
Number of silence frames before ending speech (default: 24 for v6)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sample_rate int
Audio sample rate in Hz (16000 or 8000)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited