vad_invalidate_callback method
Invalidate the callback to prevent it from being invoked This MUST be called before closing the Dart NativeCallable to prevent crashes. Uses synchronous dispatch to ensure all pending callbacks complete first. @param handle VAD handle
Implementation
void vad_invalidate_callback(ffi.Pointer<VADHandle> handle) {
return _vad_invalidate_callback(handle);
}