VADEvent class final
VAD Event structure.
Flat layout — this must match the structs actually emitted by the native
implementations (VADEventCStruct in ios/macos VadPlusFFI.swift and
VADEventC in android vad_plus_jni.cpp) and the generated Dart bindings.
Only the fields relevant to the current type are populated; the rest
are zero/NULL.
- Inheritance
- Implemented types
- Available extensions
Constructors
- VADEvent()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - error_code ↔ int
-
Error code
getter/setter pair
-
error_message
↔ Pointer<
Char> -
VAD_EVENT_ERROR
Error message
getter/setter pair
-
frame_data
↔ Pointer<
Float> -
Pointer to frame audio data (float32)
getter/setter pair
- frame_is_speech ↔ int
-
Whether current frame is speech (0 = false, 1 = true)
getter/setter pair
- frame_length ↔ int
-
Number of samples in frame
getter/setter pair
- frame_probability ↔ double
-
VAD_EVENT_FRAME_PROCESSED
Speech probability (0.0 - 1.0)
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
speech_end_audio_data
↔ Pointer<
Int16> -
VAD_EVENT_SPEECH_END
Pointer to PCM16 audio data
getter/setter pair
- speech_end_audio_length ↔ int
-
Number of samples
getter/setter pair
- speech_end_duration_ms ↔ int
-
Duration in milliseconds
getter/setter pair
- type ↔ int
-
One of the VADEventType values
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited